/**********************************************************************************************
* Device      : AD18E22X
* Author      :
* Version     : V0.0.1
* Date        : 2024.08.28
* Description :
*     VDD作基准，ADC采集FVR，产生ADC的中断，PB0翻转；
***********************************************************************************************/
#include "AD18E22X.h"
#include <stdio.h>
#include "periph.h"
#include "usart.h"

/*********************************************************************************************
*常用配置字功能说明:
*
*_FINTOSC_DIV1_1L  :  内部 RC 振荡器频率选择
*_FCPU_4T_1L       :  选择指令周期为4T模式
*_SMT_SMV_1L       :  电平选择位
*_LVREN_OFF_1L     :  LVR 使能选择           
*_LVR24V_1L        :  LVR 电压选择2.4V    
*
*_DBGEN_I2C_OFF_2L :  I2C 调试模式使能选择               
*_DBGEN_UART_00_2L :  UART 调试模式使能选择              
*_RESETE_OFF_2L    :  外部复位使能选择           
*_WDTE_OFF_2L      :  WDT 使能选择         
*_TWDT_111_2L      :  看门狗溢出时间及上电复位时间选择         
*
*注意：1.配置字若无特别需求请勿修改；
*      2.其他配置字及相应功能见Datasheet及头文件；
*
************************************************************************************************/

__CONFIG(1,_FINTOSC_DIV1_1L     & _FCPU_4T_1L         & _SMT_SMV_1L     & _LVREN_OFF_1L    & _LVR24V_1L  );
__CONFIG(2,_DBGEN_I2C_OFF_2L     & _DBGEN_UART_00_2L    & _RESETE_OFF_2L  & _WDTE_OFF_2L     & _TWDT_111_2L   );

unsigned short VOLT ;


void main(void)
{
    GPIO_Init();      //GPIO 初始化
    usart_init();     //TX_PA1
    ADC_Config();   //ADC的基准选择VDD,采集FVR；
    fvr_int();      //FVR的配置，选择VREF1P0(1.2V)通道，2倍放大
    printf("AD18E22X_ADC_FVR_TEST\r\n");
    while(1)
    {
      VOLT =ADC_SampleFilter();
      printf("ADC_Vol =  %d \r\n",VOLT);
    }
}
//中断服务函数
//高优先中断服务函数
void interrupt ISR_h(void)
{

     if(ADIE&&ADIF)
     {
       ADIF = 0;
       TRISB0  = 0;//设置PB0为输出模式
       PB0      = ~PB0; //用于检测ADC是否产生中断
     }
}
//低优先级中断服务函数
void interrupt low_priority ISR_l (void)
{


}

