/**********************************************************************************************
* Device      : AD18E22X
* Author      : ADUC AE Team
* Version     : V0.0.1
* Date        : 2024.08.24
* Description : ADC配置采集通道为NTC,参考电压为VDD，通过串口（PA1）输出对应ADC值   波特率 = 19200
***********************************************************************************************/
#include "AD18E22X.h"
#include <stdio.h>
#include "periph.h"
#include "usart.h"

/*********************************************************************************************
*常用配置字功能说明:
*
*_FINTOSC_DIV1_1L  :  内部 RC 振荡器频率选择
*_FCPU_4T_1L       :  选择指令周期为4T模式
*_SMT_SMV_1L       :  电平选择位
*_LVREN_OFF_1L     :  LVR 使能选择           
*_LVR24V_1L        :  LVR 电压选择2.4V    
*
*_DBGEN_I2C_OFF_2L :  I2C 调试模式使能选择               
*_DBGEN_UART_00_2L :  UART 调试模式使能选择              
*_RESETE_OFF_2L    :  外部复位使能选择           
*_WDTE_OFF_2L      :  WDT 使能选择         
*_TWDT_111_2L      :  看门狗溢出时间及上电复位时间选择         
*
*注意：1.配置字若无特别需求请勿修改；
*      2.其他配置字及相应功能见Datasheet及头文件；
*
************************************************************************************************/

__CONFIG(1,_FINTOSC_DIV1_1L     & _FCPU_2T_1L         & _SMT_SMV_1L     & _LVREN_OFF_1L    & _LVR24V_1L  );
__CONFIG(2,_DBGEN_I2C_OFF_2L      & _DBGEN_UART_00_2L   & _RESETE_OFF_2L  & _WDTE_OFF_2L     & _TWDT_111_2L   );

unsigned short VOLT ;

//==============================================================================================
// ----Function: 主程序
// --Parameters: None
// -----Returns: None
//---------Note: 
//==============================================================================================
void main(void)
{
    GPIO_Init();
    TRISC6=1;
    usart_init();   //TX-PA1 RX-PA4
    fvr_int();
    ADC_Config();         //ADC初始化
    
    printf("AD18E22X_test\r\n");

    while(1)
    {
      VOLT =ADC_SampleFilter();     //获取采集值
      printf("ADC_Vol =  %d \r\n",VOLT);      //打印AD转换数据

      // putch(0xaf);
      // putch(VOLT>>8);
      // putch(VOLT);
      // putch(VOLT>>8);
      // putch(VOLT);
      // putch(0xfa);

      __delay_ms(200);
    }
} 
//高优先级中断服务函数

void interrupt ISR_h (void)
{	
//进入中断后系统自动关闭中断



} 

//低优先级中断服务函数

void interrupt low_priority ISR_l (void)
{	
	

}

