/*******************************************************************************
* Device      : AD18E22X
* Author      :
* Version     : V0.0.1
* Date        : 2024.08.24
* Description : 正端选择PC1,负端选择PB1,比较结果输出到PA2；产生CMP中断，PB0翻转
* Note        :
********************************************************************************/
#include "AD18E22X.h"
#include "Periph.h"
#include "AD18E22X_DEF.h"

/*********************************************************************************************
*常用配置字功能说明:
*
*_FINTOSC_DIV1_1L  :  内部 RC 振荡器频率选择
*_FCPU_4T_1L       :  选择指令周期为4T模式
*_SMT_SMV_1L       :  电平选择位
*_LVREN_OFF_1L     :  LVR 使能选择           
*_LVR24V_1L        :  LVR 电压选择2.4V    
*
*_DBGEN_I2C_OFF_2L :  I2C 调试模式使能选择               
*_DBGEN_UART_00_2L :  UART 调试模式使能选择              
*_RESETE_OFF_2L    :  外部复位使能选择           
*_WDTE_OFF_2L      :  WDT 使能选择         
*_TWDT_111_2L      :  看门狗溢出时间及上电复位时间选择         
*
*注意：1.配置字若无特别需求请勿修改；
*      2.其他配置字及相应功能见Datasheet及头文件；
*
************************************************************************************************/
__CONFIG(1,_FINTOSC_DIV1_1L     & _FCPU_4T_1L         & _SMT_SMV_1L     & _LVREN_OFF_1L    & _LVR24V_1L  );
__CONFIG(2,_DBGEN_I2C_OFF_2L    & _DBGEN_UART_00_2L    & _RESETE_OFF_2L  & _WDTE_OFF_2L     & _TWDT_111_2L   );


void main(void)
{
	GPIO_Init();// GPIO 的初始化，上下拉关闭，开漏关闭，设置IO口为输出模式


	
	Cmp0_Cfg(CMP0PCH_PC1, CMP0NCH_PB1, CMP0INT_DOUBLEEDGE);	//Pch_PC1,Nch_PB1, PA3输出比较结果,  使用该配置时需要将PA3设置为输出模式；
	
	IPEN=1;		//高低优先级中断使能位
	GIEH=1;		//使能高优先级总中断
	GIEL=1;     //使能低优先级总中断


	TRISA2=0;   //PA2设置为输出CMP0OUT
	TRISB0=0;   //PB0设置为输出，用于检测中断是否产生
 

	while(1)
	{
		
	}

}
//高优先级中断服务函数
void interrupt ISR_h (void)
{
//进入中断后系统自动关闭中断
	if((CMP0IE==1)&&(CMP0IF==1))
	{
	   	CMP0IF=0;
		PB0=~PB0;
	}

	if((CMP1IE==1)&&(CMP1IF==1))
	{
	   	CMP1IF=0;
		// PB0=~PB0;
	}
}

//低优先级中断服务函数

void interrupt low_priority ISR_l (void)
{


}
