/*******************************************************************************
* Device      : AD18E22X
* Author      : XAD SE Team
* Version     : V0.0.1
* Date        : 20220825
* Description : 系统外设驱动函数
********************************************************************************/

/********************************INCLUDES*************************************/

#include <stdio.h>
#include "AD18E22X.h"
#include "Periph.h"
#include "AD18E22X_DEF.h"

/*********************************************************/

void GPIO_Init(void)
{
     TRISA = 0X00;       //PA口设置为输出模式
     PA0PU = 1;          //PA0上拉关闭
     PA1PU = 1;          //PA1上拉关闭
     PA2PU = 1;          //PA2上拉关闭
     PA4PU = 1;          //PA4上拉关闭
     PA5PU = 1;          //PA5上拉关闭
     PAPD  = 0x3F;       //PA口下拉关闭
     PA0OD = 0;          //PA0 OD关闭
     PA1OD = 0;          //PA1 OD关闭
     PA2OD = 0;          //PA2 OD关闭
     PA4OD = 0;          //PA4 OD关闭
     PA5OD = 0;          //PA5 OD关闭
     TRISB = 0X00;       //PB口设置为输出模式
     PBPU  = 0x3F;       //PB口上拉关闭
     TRISC = 0X00;       //PC口设置为输出模式
     PCPU  = 0x7F;       //PC上拉关闭
     PC6=1;              //注：PC6在低功耗模式下需要关闭上拉并且输出高
     PC6PD = 1;          //PC6口下拉关闭  PC6控制PMOS时需要设置成输入模式，
                         //通过控制上下拉电阻1K实现PMOS开关，减少PMOS开关导致电源电压过充现象
}


/***************************************************************
Pch:0-PC1,1-PB0,2-PC5,3-PB2,4-PB4,5-PB3,6-FVR,7-DAC
Nch:0-PC0,1-PB1,2-PA1,3-PC4,4-PA4,5-PA5,6-FVR,7-DAC
Mode:
*    CMP0INT_DIS             (0 << 2)//不产生中断
*    CMP0INT_RISEEDGE        (1 << 2)//上升沿触发中断
*    CMP0INT_FALLEDGE        (2 << 2)//下降沿触发中断
*    CMP0INT_DOUBLEEDGE      (3 << 2)//双沿触发中断
****************************************************************/
void Cmp0_Cfg(unsigned char Pch,unsigned char Nch,unsigned char Mode)
{

	TRISC1 = 1;PC1PU = 1;TRISB1 = 1;PB1PU = 1;//比较器输入IO需设置成输出状态

	CMP0CON0 = 0;
	CMP0CON1 = 0;
	CMP0CON0 = CMP0_EN|Pch|Nch;	//CMP使能
	CMP0CON1 = CMPFILTER|Mode|CMP0OUT_PA2_EN|CMP0HYS_EN;//滤波时间，触发中断？，PA2输出CMPOUT，CMP0迟滞使能

	CMP0POSE  = CMPPOSE_FORWARD;//输出极性：0-正向，1-反向
	CMPCLK_CS = CMPCLK_FCPU;//时钟: 0-FCPU, 1-OSC32K

     CMP0IF=0;      //初始化CMP的中断标志位；
	CMP0IE=1;      //CMP的中断允许使能位，使能之后才可以进中断服务函数
	CMP0IP=1;	     //CMP高优先级使能
}

/***************************************************************
Pch:0-PC1,1-PB0,2-PC5,3-PB2,4-PB4,5-PB3,6-FVR,7-DAC
Nch:0-PC0,1-PB1,2-PA1,3-PC4,4-PA4,5-PA5,6-FVR,7-DAC
Mode:
    CMP1INT_DIS             (0 << 2)//不产生中断
    CMP1INT_RISEEDGE        (1 << 2)//上升沿触发中断
    CMP1INT_FALLEDGE        (2 << 2)//下降沿触发中断
    CMP1INT_DOUBLEEDGE      (3 << 2)//双沿触发中断
****************************************************************/
void Cmp1_Cfg(unsigned char Pch,unsigned char Nch,unsigned char Mode)
{

	TRISC1 = 1;PC1PU = 1;TRISB1 = 1;PB1PU = 1;//比较器输入IO需设置成输出状态

	CMP1CON0 = 0;
	CMP1CON1 = 0;
	CMP1CON0 = CMP1_EN|Pch|Nch;	//CMP使能
	CMP1CON1 = CMPFILTER|Mode|CMP1OUT_PA3_EN|CMP1HYS_EN;     //滤波时间，触发中断？，PA3输出CMPOUT，CMP1迟滞使能

	CMP1POSE  = CMPPOSE_FORWARD;//输出极性：0-正向，1-反向
	CMPCLK_CS = CMPCLK_FCPU;//时钟: 0-FCPU, 1-OSC32K

     CMP1IF=0; //初始化CMP的中断标志位；
	CMP1IE=1; //CMP的中断允许使能位，使能之后才可以进中断服务函数
	CMP1IP=1;	//CMP高优先级使能
}
