/**********************************************************************************************
* Device      : AD18E22X
* Author      : fengxuanmian
* Version     : V0.0.1
* Date        : 2024.08.24
* Description : 配置字中选择2T模式(一个指令周期为两个机器周期)
*               使用系统时钟作为tmr0的计数时钟源,2分频,打开buzzer PA0将输出20K的buzzer信号
*               配置字中也可选择4T模式(一个指令周期为四个机器周期)
*               使用系统时钟作为tmr0的计数时钟源,2分频,打开buzzer PA0将输出10K的buzzer信号
***********************************************************************************************/

#include "AD18E22X.h"
#include "AD18E22X_DEF.h"

/*********************************************************************************************
*常用配置字功能说明:
*
*_FINTOSC_DIV1_1L  :  内部 RC 振荡器频率选择
*_FCPU_4T_1L       :  选择指令周期为4T模式
*_SMT_SMV_1L       :  电平选择位
*_LVREN_OFF_1L     :  LVR 使能选择           
*_LVR24V_1L        :  LVR 电压选择2.4V    
*
*_DBGEN_I2C_OFF_2L :  I2C 调试模式使能选择               
*_DBGEN_UART_00_2L :  UART 调试模式使能选择              
*_RESETE_OFF_2L    :  外部复位使能选择           
*_WDTE_OFF_2L      :  WDT 使能选择         
*_TWDT_111_2L      :  看门狗溢出时间及上电复位时间选择         
*
*注意：1.配置字若无特别需求请勿修改；
*      2.其他配置字及相应功能见Datasheet及头文件；
*
************************************************************************************************/

__CONFIG(1,_FINTOSC_DIV1_1L     & _FCPU_4T_1L         & _SMT_SMV_1L     & _LVREN_OFF_1L    & _LVR24V_1L  );
__CONFIG(2,_DBGEN_I2C_OFF_2L     & _DBGEN_UART_00_2L    & _RESETE_OFF_2L  & _WDTE_OFF_2L     & _TWDT_111_2L   );

/*        时钟频率/计数分频/指令周期 = 计数频率    (指令周期选择为4T)
                16M/2/4  =  2M
         一次计数时间:1s/2000000 = 0.5us
BUZZER 10Khz(中断周期20K)  需要计数 0.05ms/0.5us = 100   故T0周期取100*/

/*        时钟频率/计数分频/指令周期 = 计数频率    (指令周期选择为2T)
                16M/2/2  =  4M
         一次计数时间:1s/4000000 = 0.25us
BUZZER 20Khz(中断周期40K)  需要计数 0.025ms/0.25us = 100   故T0周期取100*/
//---------配置字 FCPU 可选--------------
//_FCPU_4T_1L         4T模式
//_FCPU_2T_1L         2T模式
//------------------------
void GPIO_Init(void);
void main (void)
{
	GPIO_Init();
  	//时钟源选择CPU(16M)   T0使能分频   2分频
       TRISA0 = 0;            //PA0设置输出

       T0CON = BUZZER_EN|T0CS_CPU|PSA_EN|T0CKPS_DIV2;
	PR0 = 100;            //计数周期
	TMR0 = 0;             //计数初值
	

	while(1)
	{

	}
}

//高优先级中断服务函数
void interrupt ISR_h (void)
{
//当前范例未使用
}

//低优先级中断服务函数
void interrupt low_priority ISR_l (void)
{
//当前范例未使用
}


/*******************************************************************************
// ----Function: GPIO_Init
// --Parameters:
// -----Returns: None
//---------Note:所有IO初始化
*******************************************************************************/
void GPIO_Init(void)
{
     TRISA = 0X00;       //PA口设置为输出模式
     PA0PU = 1;          //PA0上拉关闭
     PA1PU = 1;          //PA1上拉关闭
     PA2PU = 1;          //PA2上拉关闭
     PA4PU = 1;          //PA4上拉关闭
     PA5PU = 1;          //PA5上拉关闭
     PAPD  = 0x3F;       //PA口下拉关闭
     PA0OD = 0;          //PA0 OD关闭
     PA1OD = 0;          //PA1 OD关闭
     PA2OD = 0;          //PA2 OD关闭
     PA4OD = 0;          //PA4 OD关闭
     PA5OD = 0;          //PA5 OD关闭
     TRISB = 0X00;       //PB口设置为输出模式
     PBPU  = 0x3F;       //PB口上拉关闭
     TRISC = 0X00;       //PC口设置为输出模式
     PCPU  = 0x7F;       //PC上拉关闭
     PC6=1;              //注：PC6在低功耗模式下需要关闭上拉并且输出高
     PC6PD = 1;          //PC6口下拉关闭  PC6控制PMOS时需要设置成输入模式，
                         //通过控制上下拉电阻1K实现PMOS开关，减少PMOS开关导致电源电压过充现象 
}