/**********************************************************************************************
* Device      : AD18E22X
* Author      :
* Version     : V0.0.1
* Date        : 2024.08.24
* Description : 1、DAC的参考电压选择FVR，通过CMP进行比较
                   CMP0 正端选择DACOUT,负端选择PB1,比较结果通过PA4输出
                   CMP1 正端选择PB2,负端选择DACOUT,比较结果通过PA5输出
*
*
*
***********************************************************************************************/

#include "AD18E22X.h"
#include <stdio.h>
#include "periph.h"
#include "AD18E22X_DEF.h"
#include "usart.h"


/*********************************************************************************************
* 常用配置字功能说明：
*
* _FINTOSC_DIV1_1L  :  内部 RC 振荡器频率选择
* _FCPU_4T_1L       ： 选择指令周期为4T模式
* _SMT_SMV_1L		： 电平选择位
* _LVREN_OFF_1L     :  LVR 使能选择
* _LVR24V_1L        ： LVR 电压选择2.4V

* _DBGEN_I2C_OFF_2L : I2C 调试模式使能选择
* _DBGEN_UART_00_2L ：UART 调试模式使能选择
* _RESETE_OFF_2L    : 外部复位使能选择
* _WDTE_OFF_2L      ：WDT 使能选择
* _TWDT_111_2L      ：看门狗溢出时间及上电复位时间选择
*
* 注意：1.配置字若无特别需求请勿修改；
*       2.其他配置字及相应功能见Datasheet及头文件；
*
************************************************************************************************/

__CONFIG(1,_FINTOSC_DIV1_1L      & _FCPU_4T_1L          & _SMT_SMV_1L     & _LVREN_OFF_1L    & _LVR24V_1L  );
__CONFIG(2,_DBGEN_I2C_OFF_2L     & _DBGEN_UART_00_2L    & _RESETE_OFF_2L  & _WDTE_OFF_2L     & _TWDT_111_2L   );




void main(void)
{
     unsigned char  i;


     GPIO_Init();//GPIO 初始化
     usart_init();
     FVR_Init(FVR_SEL_1V2,FVR_PG2);
     DAC_Config(DAC_SEL_FVR, DAC_CS00,   1,    DAC_EN  );
   
     Cmp0_Cfg(CMP0PCH_DAC,CMP0NCH_PB1,CMP0INT_DIS);
     Cmp1_Cfg(CMP1PCH_PB2,CMP1NCH_DAC,CMP1INT_DIS);

     while(1)
     {
          PA4 = CMP0OUT;
          PA5 = CMP1OUT;
     }
}

//高优先级中断服务函数

void interrupt ISR_h (void)
{
//进入中断后系统自动关闭中断



}

//低优先级中断服务函数

void interrupt low_priority ISR_l (void)
{


}


