#include <stdio.h>
#include "AD18E22X.h"
#include "periph.h"
#include "AD18E22X_DEF.h"

void GPIO_Init(void)
{
	PORTA = 0x00;
	TRISA = 0X00;       //PA口设置为输出模式
	PA0PU = 1;          //PA0上拉关闭
	PA1PU = 1;          //PA1上拉关闭
	PA2PU = 1;          //PA2上拉关闭
	PA4PU = 1;          //PA4上拉关闭
	PA5PU = 1;          //PA5上拉关闭
 	PAPD  = 0x3F;       //PA口下拉关闭
	PAOD = 0x00;          //PA0 OD关闭
	
	PORTB = 0x00;
	TRISB = 0X00;       //PB口设置为输出模式
	PBPU  = 0x3F;       //PB口上拉关闭

	PORTC = 0x00;
	TRISC = 0X00;       //PC口设置为输出模式
	PCPU  = 0x7F;       //PC上拉关闭
	PC6=1;              //注：PC6在低功耗模式下需要关闭上拉并且输出高
	PC6PD = 1;          //PC6口下拉关闭  PC6控制PMOS时需要设置成输入模式，
                         //通过控制上下拉电阻1K实现PMOS开关，减少PMOS开关导致电源电压过充现象
}


/***************************************************************************************
*  Function  :  DAC_Config  配置DAC
*  Parameters：
*           Vref：参考电压
*                             DAC_SEL_VDD             0X80//DAC参考电压选择VDD
*                             DAC_SEL_FVR             0X00//DAC参考电压选择FVR
*           DacMode：DAC抽头选择
*                             DAC_CS00                0X00 //Vdac = (1/5)DAC_VREF+[(n+1)/40]DAC_VREF, n = DAC[3:0] in decimal  
*                             DAC_CS01                0X10 //Vdac = [(n+1)/32]DAC_VREF, n = DAC[3:0] in decimal
*                             DAC_CS10                0X20 //VDAC = (1/4)DAC_VREF+[(n+1)/32]DAC_VREF, n = DAC[3:0] in decimal
*                             DAC_CS11                0X30  //Vdac = [(n+1)/24]DAC_VREF, n = DAC[3:0] in decimal  
*           Data：输出电压值选择   0 ~ 15
*           state：DAC使能                 
*                             DAC_EN     1     //使能DAC
*                             DAC_DIS    0     //禁止DAC
*
*
******************************************************************************************/

void DAC_Config(unsigned char Vref,unsigned char DacMode,unsigned char Data,unsigned char state)
{
	DACCON = 0x00;
	DACCON = Vref|DacMode|Data|state;         //参考电压

	printf("DACCON =%d,\r", DACCON);
	printf("data =%d,\r", Data);
	printf("DacMode =%d,\r\n", DacMode>>4);
}

/*******************************************************************************
*   Function  :    FVR_Init   FVR配置
*   Parameters:
* FVR_SEL:FVR输入通道选择
*        FVR_SEL_1V2             (0X00 << 4)
*        FVR_SEL_DACOUT          (0X01 << 4)
*        FVR_SEL_NTC             (0X02 << 4)
* FVRPGA:FVR 电压放大倍数选择
*        FVR_PG1                 (0X01 << 1)
*        FVR_PG2                 (0X02 << 1)
*        FVR_PG3                 (0X03 << 1)
 * *********************************************************************************/

void FVR_Init(unsigned char FVR_SEL,unsigned char FVRPGA)
{
	FVRCON = 0X00;
	FVRCON = FVR_SEL|FVRPGA|FVR_EN;//使能FVR，FVR的放大倍数选择2倍，通道选择VREF1V2；
	
}

/***************************************************************
Pch:0-PC1,1-PB0,2-PC5,3-PB2,4-PB4,5-PB3,6-FVR,7-DAC
Nch:0-PC0,1-PB1,2-PA1,3-PC4,4-PA4,5-PA5,6-FVR,7-DAC
Mode:
*    CMP0INT_DIS             (0 << 2)//不产生中断
*    CMP0INT_RISEEDGE        (1 << 2)//上升沿触发中断
*    CMP0INT_FALLEDGE        (2 << 2)//下降沿触发中断
*    CMP0INT_DOUBLEEDGE      (3 << 2)//双沿触发中断
****************************************************************/
void Cmp0_Cfg(unsigned char Pch,unsigned char Nch,unsigned char Mode)
{

	TRISB1 = 1;PB1PU = 1;//比较器输入IO需设置成输出状态

	CMP0CON0 = 0;
	CMP0CON1 = 0;
	CMP0CON0 = CMP0_EN|Pch|Nch;	//CMP使能
	CMP0CON1 = CMPFILTER|Mode|CMP0HYS_EN;     //滤波时间，不触发中断，CMP0迟滞使能

	CMP0POSE  = CMPPOSE_FORWARD;//输出极性：0-正向，1-反向
	CMPCLK_CS = CMPCLK_FCPU;//时钟: 0-FCPU, 1-OSC32K
}

/***************************************************************
Pch:0-PC1,1-PB0,2-PC5,3-PB2,4-PB4,5-PB3,6-FVR,7-DAC
Nch:0-PC0,1-PB1,2-PA1,3-PC4,4-PA4,5-PA5,6-FVR,7-DAC
Mode:
    CMP1INT_DIS             (0 << 2)//不产生中断
    CMP1INT_RISEEDGE        (1 << 2)//上升沿触发中断
    CMP1INT_FALLEDGE        (2 << 2)//下降沿触发中断
    CMP1INT_DOUBLEEDGE      (3 << 2)//双沿触发中断
****************************************************************/
void Cmp1_Cfg(unsigned char Pch,unsigned char Nch,unsigned char Mode)
{

	TRISB2 = 1;PB2PU = 1;//比较器输入IO需设置成输出状态

	CMP1CON0 = 0;
	CMP1CON1 = 0;
	CMP1CON0 = CMP1_EN|Pch|Nch;	//CMP使能
	CMP1CON1 = CMPFILTER|Mode|CMP1HYS_EN;     //滤波时间，不触发中断，CMP0迟滞使能

	CMP1POSE  = CMPPOSE_FORWARD;//输出极性：0-正向，1-反向
	CMPCLK_CS = CMPCLK_FCPU;//时钟: 0-FCPU, 1-OSC32K
}
