/**********************************************************************************************
* Device      : AD18E22X
* Author      :
* Version     : V0.0.1
* Date        : 2024.08.24
* Description : 1、DAC的参考电压选择VDD，DACOUT可以通过FVR输出到PA2 PA3，
*                  ADC采集DACOUT电压               
*
*
*
***********************************************************************************************/

#include "AD18E22X.h"
#include <stdio.h>
#include "periph.h"
#include "AD18E22X_DEF.h"
#include "usart.h"


/*********************************************************************************************
* 常用配置字功能说明：
*
* _FINTOSC_DIV1_1L  :  内部 RC 振荡器频率选择
* _FCPU_4T_1L       ： 选择指令周期为4T模式
* _SMT_SMV_1L		： 电平选择位
* _LVREN_OFF_1L     :  LVR 使能选择
* _LVR24V_1L        ： LVR 电压选择2.4V

* _DBGEN_I2C_OFF_2L : I2C 调试模式使能选择
* _DBGEN_UART_00_2L ：UART 调试模式使能选择
* _RESETE_OFF_2L    : 外部复位使能选择
* _WDTE_OFF_2L      ：WDT 使能选择
* _TWDT_111_2L      ：看门狗溢出时间及上电复位时间选择
*
* 注意：1.配置字若无特别需求请勿修改；
*       2.其他配置字及相应功能见Datasheet及头文件；
*
************************************************************************************************/

__CONFIG(1,_FINTOSC_DIV1_1L      & _FCPU_4T_1L          & _SMT_SMV_1L     & _LVREN_OFF_1L    & _LVR24V_1L  );
__CONFIG(2,_DBGEN_I2C_OFF_2L     & _DBGEN_UART_00_2L    & _RESETE_OFF_2L  & _WDTE_OFF_2L     & _TWDT_111_2L   );


volatile unsigned char Chip_ID = 0;
unsigned short VOLT ;
unsigned int SUM_VOLT ;


void main(void)
{
     unsigned char  i;
     SUM_VOLT = 0;

     GPIO_Init();//GPIO 初始化
     usart_init();
     DAC_Config(    DAC_SEL_VDD,        DAC_CS00,    0,        DAC_EN  );
     ADC_Config();         //ADC初始化

     FVR_Init(FVR_SEL_DACOUT,FVR_PG1);
     
     __delay_ms(1000);
     while(1)
     {
         for ( i = 0; i < 16; i++)
         {
               TRISB0 =0;
               PB0 = 1;
              
               DAC_Config(DAC_SEL_VDD, DAC_CS00,   i,    DAC_EN  );
               __delay_ms(500);

               for(int j = 0;j<16;j++){
                    VOLT =ADC_SampleFilter();     //获取采集值
                    SUM_VOLT +=VOLT;
               }
               printf("SUM_VOLT =  %d \r\n",SUM_VOLT>>4);      //打印AD转换数据
               SUM_VOLT = 0;

            
               __delay_ms(1000);
               PB0 = 0;
               __delay_ms(500);
          }

          for ( i = 0; i < 16; i++)
         {
               TRISB0 =0;
               PB0 = 1;
               
               DAC_Config(DAC_SEL_VDD, DAC_CS01,   i,    DAC_EN  );

               __delay_ms(500);

               for(int j = 0;j<16;j++){
                    VOLT =ADC_SampleFilter();     //获取采集值
                    SUM_VOLT +=VOLT;
               }
               printf("SUM_VOLT =  %d \r\n",SUM_VOLT>>4);      //打印AD转换数据
               SUM_VOLT = 0;

               __delay_ms(1000);
               PB0 = 0;
               __delay_ms(500);
          }
          for ( i = 0; i < 16; i++)
         {
               TRISB0 =0;
               PB0 = 1;
               
               DAC_Config(DAC_SEL_VDD, DAC_CS10,   i,    DAC_EN  );

               __delay_ms(500);

               for(int j = 0;j<16;j++){
                    VOLT =ADC_SampleFilter();     //获取采集值
                    SUM_VOLT +=VOLT;
               }
               printf("SUM_VOLT =  %d \r\n",SUM_VOLT>>4);      //打印AD转换数据
               SUM_VOLT = 0;

            
               __delay_ms(1000);
               PB0 = 0;
               __delay_ms(500);
          }

       for ( i = 0; i < 16; i++)
         {
               TRISB0 =0;
               PB0 = 1;
              
               DAC_Config(DAC_SEL_VDD, DAC_CS11,   i,    DAC_EN  );
               
                 __delay_ms(500);

               for(int j = 0;j<16;j++){
                    VOLT =ADC_SampleFilter();     //获取采集值
                    SUM_VOLT +=VOLT;
               }
               printf("SUM_VOLT =  %d \r\n",SUM_VOLT>>4);      //打印AD转换数据
               SUM_VOLT = 0;

         
               __delay_ms(1000);
               PB0 = 0;
               __delay_ms(500);
          }

     }
}

//高优先级中断服务函数

void interrupt ISR_h (void)
{
//进入中断后系统自动关闭中断



}

//低优先级中断服务函数

void interrupt low_priority ISR_l (void)
{


}


