#include <stdio.h>
#include "AD18E22X.h"
#include "periph.h"
#include "AD18E22X_DEF.h"

void GPIO_Init(void)
{
	PORTA = 0x00;
	TRISA = 0X00;       //PA口设置为输出模式
	PA0PU = 1;          //PA0上拉关闭
	PA1PU = 1;          //PA1上拉关闭
	PA2PU = 1;          //PA2上拉关闭
	PA4PU = 1;          //PA4上拉关闭
	PA5PU = 1;          //PA5上拉关闭
  PAPD  = 0x3F;       //PA口下拉关闭
	PAOD = 0x00;          //PA0 OD关闭
	
	PORTB = 0x00;
	TRISB = 0X00;       //PB口设置为输出模式
	PBPU  = 0x3F;       //PB口上拉关闭

	PORTC = 0x00;
	TRISC = 0X00;       //PC口设置为输出模式
	PCPU  = 0x7F;       //PC上拉关闭
	PC6=1;              //注：PC6在低功耗模式下需要关闭上拉并且输出高
	PC6PD = 1;          //PC6口下拉关闭  PC6控制PMOS时需要设置成输入模式，
                         //通过控制上下拉电阻1K实现PMOS开关，减少PMOS开关导致电源电压过充现象
}


/***************************************************************************************
*  Function  :  DAC_Config  配置DAC
*  Parameters：
*           Vref：参考电压
*                             DAC_SEL_VDD             0X80//DAC参考电压选择VDD
*                             DAC_SEL_FVR             0X00//DAC参考电压选择FVR
*           DacMode：DAC抽头选择
*                             DAC_CS00                0X00 //Vdac = (1/5)DAC_VREF+[(n+1)/40]DAC_VREF, n = DAC[3:0] in decimal  
*                             DAC_CS01                0X10 //Vdac = [(n+1)/32]DAC_VREF, n = DAC[3:0] in decimal
*                             DAC_CS10                0X20 //VDAC = (1/4)DAC_VREF+[(n+1)/32]DAC_VREF, n = DAC[3:0] in decimal
*                             DAC_CS11                0X30  //Vdac = [(n+1)/24]DAC_VREF, n = DAC[3:0] in decimal  
*           Data：输出电压值选择   0 ~ 15
*           state：DAC使能                 
*                             DAC_EN     1     //使能DAC
*                             DAC_DIS    0     //禁止DAC
*
*
******************************************************************************************/

void DAC_Config(unsigned char Vref,unsigned char DacMode,unsigned char Data,unsigned char state)
{
	DACCON = 0x00;
	DACCON = Vref|DacMode|Data|state;         //参考电压

	printf("DACCON =%d,\r", DACCON);
	printf("data =%d,\r", Data);
	printf("DacMode =%d,\r\n", DacMode>>4);
}

/*******************************************************************************
*   Function  :    FVR_Init   FVR配置
*   Parameters:
* FVR_SEL:FVR输入通道选择
*        FVR_SEL_1V2             (0X00 << 4)
*        FVR_SEL_DACOUT          (0X01 << 4)
*        FVR_SEL_NTC             (0X02 << 4)
* FVRPGA:FVR 电压放大倍数选择
*        FVR_PG1                 (0X01 << 1)
*        FVR_PG2                 (0X02 << 1)
*        FVR_PG3                 (0X03 << 1)
 * *********************************************************************************/

void FVR_Init(unsigned char FVR_SEL,unsigned char FVRPGA)
{
	FVRCON = 0X00;
	FVRCON = FVR_SEL|FVRPGA|FVR_EN;//使能FVR，FVR的放大倍数选择2倍，通道选择VREF1V2；
	
}

unsigned short ADC_SampleFilter(void)
{
   unsigned char  j;
   unsigned short Volt       = 0;
   unsigned char  Time_Out   = 0;
 
   for(j = 0;j<=5;j++)
   {
          GO = 1;                         //A/D转换状态位
          Time_Out = 100;                 //设置超时时间
          while(GO)                       //A/D转换正在进行
          {
            Adc_Succee = 0;
            Time_Out--;              //等待超时
            if(Time_Out == 0)        //防止程序跑到这里死掉了
            {
                ADON = 0;         //除能A/D转换器模块
                GO = 0;           //清除转换标志
                ADON = 1;         //使能能A/D转换器模块
                GO = 1;           //清除转换标志
                Adc_Succee = 1;
                break;
            }
          }
   }
   if(Adc_Succee == 0)
   {
        Volt = (ADRESH<<8)|ADRESL;//读取ADC采集值
   }
   else
   {
        Volt = 0xFFFF;
   }
   return Volt;
}


void ADC_Config(void)
{
	// TRISB1 = 1;PB1PU = 1;//采集的通道要设为输入
	ADCON0 = ADFM_RIGHT|ADC_FVR|ADC_EN;  //配置DAC为ADC采集通道，使能A/D模拟使能位
	ADCON1 = ADVREF_VDD|ACQT_15|ADCS_FSYS_8;  //参考电压选择VDD   A/D转换时钟选择FOSC/8
}


