/**********************************************************************************************
* Device      : AD18E22X
* Author      :
* Version     : V0.0.1
* Date        : 2024.08.24
* Description : 这个例程将用查询的方式采集FVR1.2电压
*               1）采集FVR，反推VDD
*				        ADC使用时，注意事项
*				        1）切换通道和参考电压，需要执行几次空转换，AD值才能稳定
*
***********************************************************************************************/
#include "AD18E22X.h"
#include <stdio.h>
#include "periph.h"
#include "usart.h"
#include "AD18E22X_DEF.h"

/*********************************************************************************************
*常用配置字功能说明:
*
*_FINTOSC_DIV1_1L  :  内部 RC 振荡器频率选择
*_FCPU_4T_1L       :  选择指令周期为4T模式
*_SMT_SMV_1L       :  电平选择位
*_LVREN_OFF_1L     :  LVR 使能选择           
*_LVR24V_1L        :  LVR 电压选择2.4V    
*
*_DBGEN_I2C_OFF_2L :  I2C 调试模式使能选择               
*_DBGEN_UART_00_2L :  UART 调试模式使能选择              
*_RESETE_OFF_2L    :  外部复位使能选择           
*_WDTE_OFF_2L      :  WDT 使能选择         
*_TWDT_111_2L      :  看门狗溢出时间及上电复位时间选择         
*
*注意：1.配置字若无特别需求请勿修改；
*      2.其他配置字及相应功能见Datasheet及头文件；
*
************************************************************************************************/

__CONFIG(1,_FINTOSC_DIV1_1L     & _FCPU_2T_1L         & _SMT_SMV_1L     & _LVREN_OFF_1L    & _LVR24V_1L  );
__CONFIG(2,_DBGEN_I2C_OFF_2L     & _DBGEN_UART_00_2L    & _RESETE_OFF_2L  & _WDTE_OFF_2L     & _TWDT_111_2L   );

void ADC_SampleVDD(void);

volatile unsigned short Vol_VDD = 0;		//VDD电压值（mV）
volatile unsigned short AD_VDD  = 0;		//反推VDD的AD值（VDD做参考，FVR1.0V的AD值）
//==============================================================================================
// ----Function: 主函数
// --Parameters: None
// -----Returns: None
//---------Note: 这个例程将用查询的方式采集FVR1.0电压
//				 	1）采集FVR，反推VDD
//				 ADC使用时，注意事项
//					1）切换通道和参考电压，需要执行几次空转换，AD值才能稳定
//**********************************************************************************************
//==============================================================================================

void main(void)
{
    GPIO_Init();//GPIO 初始化
    TRISC6=1;
    usart_init(); //TX_PA1
    ADC_Config();  //ADC的基准选择VDD,采集通道为FVROUT；
    fvr_int();     //FVR的配置，选择VREF1P2(1.2V)通道

    printf("AD18E22X_ADC_test\r\n");

    while(1)
    {
      ADC_SampleVDD();
      // putch(0xaf);
      // putch(Vol_VDD>>8);
      // putch(Vol_VDD);
      // putch(AD_VDD>>8);
      // putch(AD_VDD);
      // putch(0xfa);
      printf("VDD = %4dmV,", Vol_VDD);		//Vol_VDD-转换过来的VDD电压值
      // printf(" %4d --- \r\n", AD_VDD);			//AD_VDD-实际采集的ADC值
    }
}
//中断服务函数
//高优先中断服务函数
void interrupt ISR_h(void)
{
     if(ADIE&&ADIF)
     {
       ADIF = 0;
       TRISB0  = 0;//设置PB0为输出模式
       PB0      = ~PB0; //用于检测ADC是否产生中断
     }
}
//低优先级中断服务函数
void interrupt low_priority ISR_l (void)
{


}

/*******************************************************************************
* Description    : AD采集FVR1.0V电压值，反推VDD电压
* Input          : None
* Output         : None
* Return         : None
* Note           :
*******************************************************************************/
void ADC_SampleVDD(void)
{
    volatile unsigned long Sum;
    volatile unsigned short ADData;
	volatile unsigned char  i;


    //空转换10次
	for(i=0; i<10; i++)
	{
        ADC_Exce();
	}
    //启动AD转换
	Sum = 0;
	for(i=0; i<8; i++)
	{
        ADC_Exce();

        //读取转换结果
        ADData = (ADRESH<<8)|ADRESL;
        Sum += ADData;
	}
	// 电压单位1mV
	AD_VDD  = Sum >> 3;
	Vol_VDD = 4915200 / AD_VDD;		//VCC采集1.2V电压：4915200=4096*1200
}

