/*******************************************************************************
* Device      : AD18E22X
* Author      :
* Version     : V0.0.1
* Date        : 2024.08.24
* Description : 测试GPIO的sink电流(灌电流)
* Note		  :
********************************************************************************/

/*********************************************************************************************
*常用配置字功能说明:
*
*_FINTOSC_DIV1_1L  :  内部 RC 振荡器频率选择
*_FCPU_4T_1L       :  选择指令周期为4T模式
*_SMT_SMV_1L       :  电平选择位
*_LVREN_OFF_1L     :  LVR 使能选择           
*_LVR24V_1L        :  LVR 电压选择2.4V    
*
*_DBGEN_I2C_OFF_2L :  I2C 调试模式使能选择               
*_DBGEN_UART_00_2L :  UART 调试模式使能选择              
*_RESETE_OFF_2L    :  外部复位使能选择           
*_WDTE_OFF_2L      :  WDT 使能选择          
*_TWDT_111_2L      :  看门狗溢出时间及上电复位时间选择         
*
*注意：1.配置字若无特别需求请勿修改；
*      2.其他配置字及相应功能见Datasheet及头文件；
*
************************************************************************************************/
#include "AD18E22X.h"

__CONFIG(1,_FINTOSC_DIV1_1L     & _FCPU_4T_1L         & _SMT_SMV_1L     & _LVREN_OFF_1L    & _LVR24V_1L  );
__CONFIG(2,_DBGEN_I2C_OFF_2L     & _DBGEN_UART_00_2L    & _RESETE_OFF_2L  & _WDTE_OFF_2L     & _TWDT_111_2L   );

void GPIO_Init(void)
{
     TRISA = 0X00;       //PA口设置为输出模式
     PA0PU = 1;          //PA0上拉关闭
     PA1PU = 1;          //PA1上拉关闭
     PA2PU = 1;          //PA2上拉关闭
     PA4PU = 1;          //PA4上拉关闭
     PA5PU = 1;          //PA5上拉关闭
     PAPD  = 0x3F;       //PA口下拉关闭
     PA0OD = 0;          //PA0 OD关闭
     PA1OD = 0;          //PA1 OD关闭
     PA2OD = 0;          //PA2 OD关闭
     PA4OD = 0;          //PA4 OD关闭
     PA5OD = 0;          //PA5 OD关闭
     TRISB = 0X00;       //PB口设置为输出模式
     PBPU  = 0x3F;       //PB口上拉关闭
     TRISC = 0X00;       //PC口设置为输出模式
     PCPU  = 0x7F;       //PC上拉关闭
     PC6=1;              //注：PC6在低功耗模式下需要关闭上拉并且输出高
     PC6PD = 1;          //PC6口下拉关闭  PC6控制PMOS时需要设置成输入模式，
                         //通过控制上下拉电阻1K实现PMOS开关，减少PMOS开关导致电源电压过充现象       
}

void main(void)
{
    GPIO_Init();
    TRISA  = 0x00;//设置PA口为输出
    TRISB  = 0x00;//设置PB口为输出
    TRISC  = 0x00;//设置PC口为输出

	PORTA  = 0x00;//PA口输出低电平
	PORTB  = 0x00;//PB口输出低电平
    PORTC  = 0x00;//PB口输出低电平

	IOCUR = 0x00;//配置PA口、PB口和PC口的驱动小电流寄存器
    // IOCUR = 0xFF;//配置PA口、PB口和PC口的驱动大电流寄存器

	while(1);

}
//高优先级中断服务函数

void interrupt ISR_h (void)
{
//进入中断后系统自动关闭中断



}

//低优先级中断服务函数

void interrupt low_priority ISR_l (void)
{


}

