/*******************************************************************************
* Device      : AD18E22X
* Author      :
* Version     : V0.0.1
* Date        : 20203509
* Description : PC口的上升沿中断，通过PA4的翻转查看PC的高优先级中断是否产生，PA4翻转PC口产生中断。否则PC口未产生中断
* Note		    : 
********************************************************************************/

/*********************************************************************************************
*常用配置字功能说明:
*
*_FINTOSC_DIV1_1L  :  内部 RC 振荡器频率选择
*_FCPU_4T_1L       :  选择指令周期为4T模式
*_SMT_SMV_1L       :  电平选择位
*_LVREN_OFF_1L     :  LVR 使能选择           
*_LVR24V_1L        :  LVR 电压选择2.4V    
*
*_DBGEN_I2C_OFF_2L :  I2C 调试模式使能选择               
*_DBGEN_UART_00_2L :  UART 调试模式使能选择              
*_RESETE_OFF_2L    :  外部复位使能选择           
*_WDTE_OFF_2L      :  WDT 使能选择         
*_TWDT_111_2L      :  看门狗溢出时间及上电复位时间选择         
*
*注意：1.配置字若无特别需求请勿修改；
*      2.其他配置字及相应功能见Datasheet及头文件；
*
************************************************************************************************/
#include "AD18E22X.h"

__CONFIG(1,_FINTOSC_DIV1_1L     & _FCPU_4T_1L         & _SMT_SMV_1L     & _LVREN_OFF_1L    & _LVR24V_1L  );
__CONFIG(2,_DBGEN_I2C_OFF_2L    & _DBGEN_UART_00_2L    & _RESETE_OFF_2L  & _WDTE_OFF_2L     & _TWDT_111_2L   );

void GPIO_Init(void)
{
     TRISA = 0X00;       //PA口设置为输出模式
     PA0PU = 1;          //PA0上拉关闭
     PA1PU = 1;          //PA1上拉关闭
     PA2PU = 1;          //PA2上拉关闭
     PA4PU = 1;          //PA4上拉关闭
     PA5PU = 1;          //PA5上拉关闭
     PAPD  = 0x3F;       //PA口下拉关闭
     PA0OD = 0;          //PA0 OD关闭
     PA1OD = 0;          //PA1 OD关闭
     PA2OD = 0;          //PA2 OD关闭
     PA4OD = 0;          //PA4 OD关闭
     PA5OD = 0;          //PA5 OD关闭
     TRISB = 0X00;       //PB口设置为输出模式
     PBPU  = 0x3F;       //PB口上拉关闭
     TRISC = 0X00;       //PC口设置为输出模式
     PCPU  = 0x7F;       //PC上拉关闭
     PC6=1;              //注：PC6在低功耗模式下需要关闭上拉并且输出高
     PC6PD = 1;          //PC6口下拉关闭  PC6控制PMOS时需要设置成输入模式，
                         //通过控制上下拉电阻1K实现PMOS开关，减少PMOS开关导致电源电压过充现象        
}


void main(void)
{
    GPIO_Init();
    TRISC   = 0x7F; //设置PB口为输入
    PCPU    = 0x7F;	//关闭PB口的上拉
    PC6PD = 0; 

    TRISA4  = 0; //设置PA0口为输出
    TRISA5  = 0; //设置PA1口为输出
    PAPU    = 0x3F; //关闭PA口的上拉
    PAPD    = 0x3F;//关闭PA口的下拉
    PAOD    = 0x00; //关闭PA口的开漏

    // PCINTMASK |=(1<<0); // 使能PC0的输入改变中断控制位
    // PCINTMASK |=(1<<1); // 使能PC1的输入改变中断控制位
    PCINTMASK |=(1<<2); // 使能PC2的输入改变中断控制位
    // PCINTMASK |=(1<<3); // 使能PC3的输入改变中断控制位
    // PCINTMASK |=(1<<4); // 使能PC4的输入改变中断控制位
    // PCINTMASK |=(1<<5); // 使能PC5的输入改变中断控制位
    // PCINTMASK |=(1<<6); // 使能PC6的输入改变中断控制位

    PCIP  = 1;//PC口的高优先级使能位
    PCIE  = 1;//PC口的中断允许位，使能之后才可以进中断服务函数
    PCIF  = 0;//PC口的中断标志位

    IPEN  = 1;//高低优先级中断使能位
	  GIEH  = 1;//使能高优先级总中断
    GIEL  = 0;//使能低优先级总中断
    
	  while(1)
    {
        PA0=~PA0;
        __delay_us(100);
    }

}

//高优先级中断服务函数
void interrupt ISR_h (void)
{
  unsigned char tmp_int;
  tmp_int=PIR2;
  if(((tmp_int&0X80)==0X80)&&(PCIE==1))
  // if((PCIF==1)&&(PCIE==1))
  {
	   PCIF = 0;
	   PA4  = ~PA4;//用于检测PB的高优先中断产生
  }
}
//低优先级中断服务函数
void interrupt low_priority ISR_l (void)
{
  unsigned char tmp_int;
  tmp_int=PIR2;
  if(((tmp_int&0X80)==0X80)&&(PCIE==1))
  // if((PCIF==1)&&(PCIE==1))
  {
    PCIF = 0;
    PA5  = ~PA5;//用于检测PB的低优先中断产
  }
}
