/*******************************************************************************
* Device      : AD18E22X
* Author      : XAD Application Team
* Version     : V0.0.1
* Date        : 20220830
* Description : PA/PB/PC设置为输入状态关下拉开上拉,分别给每个IO接地,通过万用表查看对应IO的电流，根据公式R=U/I算出上拉电阻阻值
* Note		  :
********************************************************************************/

/*********************************************************************************************
*常用配置字功能说明:
*
*_FINTOSC_DIV1_1L  :  内部 RC 振荡器频率选择
*_FCPU_4T_1L       :  选择指令周期为4T模式
*_SMT_SMV_1L       :  电平选择位
*_LVREN_OFF_1L     :  LVR 使能选择           
*_LVR24V_1L        :  LVR 电压选择2.4V    
*
*_DBGEN_I2C_OFF_2L :  I2C 调试模式使能选择               
*_DBGEN_UART_00_2L :  UART 调试模式使能选择              
*_RESETE_OFF_2L    :  外部复位使能选择           
*_WDTE_OFF_2L      :  WDT 使能选择         
*_TWDT_111_2L      :  看门狗溢出时间及上电复位时间选择         
*
*注意：1.配置字若无特别需求请勿修改；
*      2.其他配置字及相应功能见Datasheet及头文件；
*
************************************************************************************************/

#include "AD18E22X.h"

__CONFIG(1,_FINTOSC_DIV1_1L     & _FCPU_4T_1L         & _SMT_SMV_1L     & _LVREN_OFF_1L    & _LVR24V_1L  );
__CONFIG(2,_DBGEN_I2C_OFF_2L     & _DBGEN_UART_00_2L    & _RESETE_OFF_2L  & _WDTE_OFF_2L     & _TWDT_111_2L   );


void main(void)
{  

  TRISA   = 0x3F; //设置PA口为输入
  TRISB   = 0x3F; //设置PB口为输入
  TRISC   = 0x7F; //设置PC口为输入

  PAPU    = 0x00; //打开PA口的上拉
  PBPU    = 0x00;	//打开PB口的上拉
  PCPU    = 0x00; //打开PC口的上拉
  PC6PU   = 0;    //打开PC6口的上拉

  PAPD    = 0x3F; //关闭PA口的下拉
  PC6PD   = 1;    //关闭PC6口的下拉

  PAOD    = 0x00; //关闭PA口的开漏

	while(1);

}
//高优先级中断服务函数

void interrupt ISR_h (void)
{
//进入中断后系统自动关闭中断



}

//低优先级中断服务函数

void interrupt low_priority ISR_l (void)
{


}

