/**********************************************************************************************
* Device      : AD18E22X
* Author      : ADUC AE Team
* Version     : V0.0.1
* Date        : 2024.08.24
* Description : DEEPPWASAVE模式，PB5为唤醒IO;在DEEPPWSAVE状态下，PB5边沿唤醒，通过PB2反转查看
***********************************************************************************************/
#include "AD18E22X.h"
#include <stdio.h>
#include "periph.h"
/*********************************************************************************************
*常用配置字功能说明:
*
*_FINTOSC_DIV1_1L  :  内部 RC 振荡器频率选择
*_FCPU_4T_1L       :  选择指令周期为4T模式
*_SMT_SMV_1L       :  电平选择位
*_LVREN_OFF_1L     :  LVR 使能选择           
*_LVR24V_1L        :  LVR 电压选择2.4V    
*
*_DBGEN_I2C_OFF_2L :  I2C 调试模式使能选择               
*_DBGEN_UART_00_2L :  UART 调试模式使能选择              
*_RESETE_OFF_2L    :  外部复位使能选择           
*_WDTE_OFF_2L      :  WDT 使能选择         
*_TWDT_111_2L      :  看门狗溢出时间及上电复位时间选择         
*
*注意：1.配置字若无特别需求请勿修改；
*      2.其他配置字及相应功能见Datasheet及头文件；
*
************************************************************************************************/

__CONFIG(1,_FINTOSC_DIV1_1L     & _FCPU_4T_1L         & _SMT_SMV_1L     & _LVREN_OFF_1L    & _LVR24V_1L  );
__CONFIG(2,_DBGEN_I2C_OFF_2L     & _DBGEN_UART_00_2L    & _RESETE_OFF_2L  & _WDTE_OFF_2L     & _TWDT_111_2L   );

unsigned char i;
volatile unsigned char tmp=0;

//==============================================================================================
// ----Function: 主程序
// --Parameters: None
// -----Returns: None
//---------Note:
//==============================================================================================
void main(void)
{

	GPIO_init();
	INTER_init();

	while(1)
	{
		for(i=0;i<10;i++)
		{
			PB2=~PB2;
			__delay_us(5000);
		}
		PB2=0;
        PBIF=0;
        tmp=PINB;          	//锁存PINB状态
        PBIE=1;
		SLEEP_PWDEEP();			//5V   2.0uA

		PBIF=0;
        PBIE=0;
	}
}

//高优先级中断服务函数

void interrupt ISR_h (void)
{
//进入中断后系统自动关闭中断



}

//低优先级中断服务函数

void interrupt low_priority ISR_l (void)
{


}

