/*******************************************************************************
* Device      : AD18E22X
* Author      :
* Version     : V0.0.1
* Date        : 20240824
* Description : 演示进入PWOFF低功耗模式，并通过产生IO中断（PBIF）进行唤醒的功能。
*               进入PWOFF模式之前，IO口PB2进行100次翻转，进入PWOFF模式睡眠后，IO口PB2停止翻转；
*				通过给PB0输入变化的高低电平，会在电平变化时产生PBIF中断进而唤醒PWOFF低功耗模式，唤醒后IO口PB2会再次进行翻转。
********************************************************************************/
#include "AD18E22X.h"
#include <stdio.h>

/*********************************************************************************************
*常用配置字功能说明:
*
*_FINTOSC_DIV1_1L  :  内部 RC 振荡器频率选择
*_FCPU_4T_1L       :  选择指令周期为4T模式
*_SMT_SMV_1L       :  电平选择位
*_LVREN_OFF_1L     :  LVR 使能选择           
*_LVR24V_1L        :  LVR 电压选择2.4V    
*
*_DBGEN_I2C_OFF_2L :  I2C 调试模式使能选择               
*_DBGEN_UART_00_2L :  UART 调试模式使能选择              
*_RESETE_OFF_2L    :  外部复位使能选择           
*_WDTE_OFF_2L      :  WDT 使能选择         
*_TWDT_111_2L      :  看门狗溢出时间及上电复位时间选择         
*
*注意：1.配置字若无特别需求请勿修改；
*      2.其他配置字及相应功能见Datasheet及头文件；
*
************************************************************************************************/
__CONFIG(1,_FINTOSC_DIV1_1L     & _FCPU_4T_1L         & _SMT_SMV_1L     & _LVREN_OFF_1L    & _LVR24V_1L  );
__CONFIG(2,_DBGEN_I2C_OFF_2L     & _DBGEN_UART_00_2L    & _RESETE_OFF_2L  & _WDTE_OFF_2L     & _TWDT_111_2L   );


void GPIO_init(void)
{
     TRISA = 0X00;       //PA口设置为输出模式
     PA0PU = 1;          //PA0上拉关闭
     PA1PU = 1;          //PA1上拉关闭
     PA2PU = 1;          //PA2上拉关闭
     PA4PU = 1;          //PA4上拉关闭
     PA5PU = 1;          //PA5上拉关闭
     PAPD  = 0x3F;       //PA口下拉关闭
     PA0OD = 0;          //PA0 OD关闭
     PA1OD = 0;          //PA1 OD关闭
     PA2OD = 0;          //PA2 OD关闭
     PA4OD = 0;          //PA4 OD关闭
     PA5OD = 0;          //PA5 OD关闭
     TRISB = 0X00;       //PB口设置为输出模式
     PBPU  = 0x3F;       //PB口上拉关闭
     TRISC = 0X00;       //PC口设置为输出模式
     PCPU  = 0x7F;       //PC上拉关闭
     PC6=1;              //注：PC6在低功耗模式下需要关闭上拉并且输出高
     PC6PD = 1;          //PC6口下拉关闭  PC6控制PMOS时需要设置成输入模式，
                         //通过控制上下拉电阻1K实现PMOS开关，减少PMOS开关导致电源电压过充现象
}

void main(void)
{
	unsigned char i;
    volatile unsigned char tmp=0;
	GPIO_init();

	TRISA0=1;
	TRISB0=1;	 	//PB0设为输入模式

	PORTA=0X00;
	PORTB=0X00;		//IO初始化为低电平

    PBINTMASK=0X01; //使能PB0端口电平变化中断

	PAINTMASK=0X01; //使能PA0端口电平变化中断

    IPEN=1;//允许高低优先级中断
	GIEH=1;//使能高优先级中断
	PEIE=1;//使能低优先级中断
    PBIP=1;//PB设为高优先级中断
    PBIF=0;
    PBIE=1;

    PAIP=1;//PA设为高优先级中断
    PAIF=0;
    PAIE=1;

	while(1)
	{
		for(i=0;i<100;i++)
		{
			PB2=~PB2;
			__delay_us(5000);
		}
		PB2=0;
        tmp=PINB;          	//锁存IO状态

		//SLEEP_PWDEEP();
		SLEEP_PWOFF();	//进入pwoff低功耗模式
	}
}


//中断服务函数
void __interrupt(high_priority) ISR_h(void)
{
	unsigned char tmp_int;
    tmp_int = PIR2;
	if(((tmp_int&0X40)==0X40)&&(PBIE==1))
	{
		PBIF=0;
		PA2=~PA2;
	}
	if(((tmp_int&0X20)==0X20)&&(PAIE==1))
	{
		PAIF=0;
		PA1=~PA1;
	}	
}
//低优先级中断服务函数

void interrupt low_priority ISR_l (void)
{


}

