/*******************************************************************************
* Device      : AD18E22X
* Author      :
* Version     : V0.0.1
* Date        : 20240824
* Description : 演示进入PWOFF低功耗模式，并通过复位引脚PC0产生复位进行唤醒的功能。注：PC0外部上拉
*               进入PWOFF模式之前，IO口PB2进行一定次数翻转，进入PWOFF模式睡眠后，IO口PB2停止翻转；
*				通过给复位引脚PC0输入低电平产生复位唤醒PWOFF后，将复位引脚PC0输入高电平取消复位状态后IO口PB2会再次进行翻转。
********************************************************************************/
#include "AD18E22X.h"
#include <stdio.h>

/*********************************************************************************************
*常用配置字功能说明:
*
*_FINTOSC_DIV1_1L  :  内部 RC 振荡器频率选择
*_FCPU_4T_1L       :  选择指令周期为4T模式
*_SMT_SMV_1L       :  电平选择位
*_LVREN_OFF_1L     :  LVR 使能选择           
*_LVR24V_1L        :  LVR 电压选择2.4V    
*
*_DBGEN_I2C_OFF_2L :  I2C 调试模式使能选择               
*_DBGEN_UART_00_2L :  UART 调试模式使能选择              
*_RESETE_OFF_2L    :  外部复位使能选择           
*_WDTE_OFF_2L      :  WDT 使能选择         
*_TWDT_111_2L      :  看门狗溢出时间及上电复位时间选择         
*
*注意：1.配置字若无特别需求请勿修改；
*      2.其他配置字及相应功能见Datasheet及头文件；
*
************************************************************************************************/

__CONFIG(1,_FINTOSC_DIV1_1L     & _FCPU_4T_1L         & _SMT_SMV_1L     & _LVREN_OFF_1L    & _LVR24V_1L  );
__CONFIG(2,_DBGEN_I2C_OFF_2L     & _DBGEN_UART_00_2L    & _RESETE_ON_2L  & _WDTE_OFF_2L     & _TWDT_111_2L   );

/*************************************
Funtion :GPIO初始化
Input   :None
Output  :None
*************************************/
void GPIO_init(void)
{
     TRISA = 0X00;       //PA口设置为输出模式
     PA0PU = 1;          //PA0上拉关闭
     PA1PU = 1;          //PA1上拉关闭
     PA2PU = 1;          //PA2上拉关闭
     PA4PU = 1;          //PA4上拉关闭
     PA5PU = 1;          //PA5上拉关闭
     PAPD  = 0x3F;       //PA口下拉关闭
     PA0OD = 0;          //PA0 OD关闭
     PA1OD = 0;          //PA1 OD关闭
     PA2OD = 0;          //PA2 OD关闭
     PA4OD = 0;          //PA4 OD关闭
     PA5OD = 0;          //PA5 OD关闭
     TRISB = 0X00;       //PB口设置为输出模式
     PBPU  = 0x3F;       //PB口上拉关闭
     TRISC = 0X00;       //PC口设置为输出模式
     PCPU  = 0x7F;       //PC上拉关闭
     PC6=1;              //注：PC6在低功耗模式下需要关闭上拉并且输出高
     PC6PD = 1;          //PC6口下拉关闭  PC6控制PMOS时需要设置成输入模式，
                         //通过控制上下拉电阻1K实现PMOS开关，减少PMOS开关导致电源电压过充现象
}
void main(void)
{
	unsigned char i;
	GPIO_init();

	PC0PU =0;//PC0打开上拉

	TRISC0=1;//PC0设为输入模式
	TRISB2=0;//PB2设为输出模式

	while(1)
	{
		for(i=0;i<100;i++)
		{
			PB2=~PB2;
			__delay_us(5000);
		}
		PB2=0;

		//SLEEP_PWDEEP();
		SLEEP_PWOFF();	//进入pwoff低功耗模式
	}
}

//高优先级中断服务函数

void interrupt ISR_h (void)
{
//进入中断后系统自动关闭中断



}

//低优先级中断服务函数

void interrupt low_priority ISR_l (void)
{


}

