/**********************************************************************************************
* Device      : AD18E22X
* Author      : fengxuanmian
* Version     : V0.0.1
* Date        : 2024.08.24
* Description : 配置tmr0 10ms定时(10ms产生一次中断；选择fcpu当计数时钟，使能分频，分频选择256) 每10ms PB1翻转一次
***********************************************************************************************/

#include "AD18E22X.h"
#include "AD18E22X_DEF.h"

/*********************************************************************************************
*常用配置字功能说明:
*
*_FINTOSC_DIV1_1L  :  内部 RC 振荡器频率选择
*_FCPU_4T_1L       :  选择指令周期为4T模式
*_SMT_SMV_1L       :  电平选择位
*_LVREN_OFF_1L     :  LVR 使能选择           
*_LVR24V_1L        :  LVR 电压选择2.4V    
*
*_DBGEN_I2C_OFF_2L :  I2C 调试模式使能选择               
*_DBGEN_UART_00_2L :  UART 调试模式使能选择              
*_RESETE_OFF_2L    :  外部复位使能选择           
*_WDTE_OFF_2L      :  WDT 使能选择         
*_TWDT_111_2L      :  看门狗溢出时间及上电复位时间选择         
*
*注意：1.配置字若无特别需求请勿修改；
*      2.其他配置字及相应功能见Datasheet及头文件；
*
************************************************************************************************/
__CONFIG(1,_FINTOSC_DIV1_1L     & _FCPU_4T_1L         & _SMT_SMV_1L     & _LVREN_OFF_1L    & _LVR24V_1L  );
__CONFIG(2,_DBGEN_I2C_OFF_2L    & _DBGEN_UART_00_2L   & _RESETE_OFF_2L  & _WDTE_OFF_2L     & _TWDT_111_2L   );

void GPIO_Init(void)
{
     TRISA = 0X00;       //PA口设置为输出模式
     PA0PU = 1;          //PA0上拉关闭
     PA1PU = 1;          //PA1上拉关闭
     PA2PU = 1;          //PA2上拉关闭
     PA4PU = 1;          //PA4上拉关闭
     PA5PU = 1;          //PA5上拉关闭
     PAPD  = 0x3F;       //PA口下拉关闭
     PA0OD = 0;          //PA0 OD关闭
     PA1OD = 0;          //PA1 OD关闭
     PA2OD = 0;          //PA2 OD关闭
     PA4OD = 0;          //PA4 OD关闭
     PA5OD = 0;          //PA5 OD关闭
     TRISB = 0X00;       //PB口设置为输出模式
     PBPU  = 0x3F;       //PB口上拉关闭
     TRISC = 0X00;       //PC口设置为输出模式
     PCPU  = 0x7F;       //PC上拉关闭
     PC6=1;              //注：PC6在低功耗模式下需要关闭上拉并且输出高
     PC6PD = 1;          //PC6口下拉关闭  PC6控制PMOS时需要设置成输入模式，
                         //通过控制上下拉电阻1K实现PMOS开关，减少PMOS开关导致电源电压过充现象       
}

void Timer0_Timer(unsigned char T0_CS,unsigned char T0_SE,unsigned char CS_EN,unsigned char T0_FD);

//
//         时钟频率/计数分频/指令周期 = 计数频率           (指令周期默认配置字为4T)
//              16M/256/4  =  15.625K
//     一次计数时间:1s/15625 = 0.064ms
//     需要定时10ms  需要计数 10ms/0.064ms = 156.25    故T0周期取156


void main (void)
{
	GPIO_Init();
	TRISB1 = 0;      //范例中使用PB1作为输出，由中断控制翻转

    //时钟源选择CPU(16M)  触发方式（下沿）T0使能分频   256分频
	Timer0_Timer(T0CS_CPU,T0SE_FALLEDGE,PSA_EN,T0CKPS_DIV256);        //只有使用T0CKI作为时钟源时才需要考虑配置触发方式
	TMR0IP = 1;     //设tmr0中断为高优先级
	TMR0IF = 0;     //清tmr0中断
	TMR0IE = 1;     //打开tmr0中断使能

	IPEN   = 1;	   //使能中断优先级
	GIEH   = 1;    //使能高优先级全局中断
	PEIE=1;//使能低优先级中断
	while(1)
	{
		// NOP();
	}
}

//高优先级中断服务函数
void __interrupt ISR_h(void)
{
//进入中断后系统自动关闭中断
	if((TMR0IF==1)&&(TMR0IE==1))    //tmr0定时10ms产生中断后PB1翻转
	{
		TMR0IF = 0;                      //清除中断标志
		TMR0   = 0;                       //tmr0从0开始计数
		PB1    =~ PB1;

	}
}

//低优先级中断服务函数
void interrupt low_priority ISR_l (void)
{
//当前范例未使用
}


void Timer0_Timer(unsigned char T0_CS,unsigned char T0_SE,unsigned char CS_EN,unsigned char T0_FD)
{

	if (T0_CS == T0CS_T0CKI_PA1)
	{
		TRISA1 = 1;            //PA1设置输入（使用t0cki时配置）
	}
	T0CON = 0X00;
	T0CON = T0_CS|T0_SE|CS_EN|T0_FD;       //选择计数时钟
	
	PR0 = 156;                 //tmr0计数周期
	TMR0 = 0;                  //设置tmr0初值

}

