/**********************************************************************************************
* Device      : AD18E22X
* Author      : TANWENBO
* Version     : V0.0.1
* Date        : 2024.08.24
* Description : 演示配置TMR1的脉宽检测模式并且将所得到的数据通过串口打印出来
***********************************************************************************************/

#include "AD18E22X.h"
#include <stdio.h>
#include "common.h"
#include "usart.h"
#include "AD18E22X_DEF.h"


/*********************************************************************************************
*常用配置字功能说明:
*
*_FINTOSC_DIV1_1L  :  内部 RC 振荡器频率选择
*_FCPU_4T_1L       :  选择指令周期为4T模式
*_SMT_SMV_1L       :  电平选择位
*_LVREN_OFF_1L     :  LVR 使能选择           
*_LVR24V_1L        :  LVR 电压选择2.4V    
*
*_DBGEN_I2C_OFF_2L :  I2C 调试模式使能选择               
*_DBGEN_UART_00_2L :  UART 调试模式使能选择              
*_RESETE_OFF_2L    :  外部复位使能选择           
*_WDTE_OFF_2L      :  WDT 使能选择         
*_TWDT_111_2L      :  看门狗溢出时间及上电复位时间选择         
*
*注意：1.配置字若无特别需求请勿修改；
*      2.其他配置字及相应功能见Datasheet及头文件；
*
************************************************************************************************/
__CONFIG(1,_FINTOSC_DIV1_1L     & _FCPU_4T_1L         & _SMT_SMV_1L     & _LVREN_OFF_1L    & _LVR24V_1L  );
__CONFIG(2,_DBGEN_I2C_OFF_2L    & _DBGEN_UART_00_2L    & _RESETE_OFF_2L  & _WDTE_OFF_2L     & _TWDT_111_2L   );


unsigned long  TIMER1_T=0;
uint32_t period;
uint16_t ccpr_temp;
unsigned char start_flag=1;

void main (void)
{

	GPIO_Init();     //IO初始化
	TRISC0=0;
	usart_init();	//模拟串口初始化TX-PB1
    printf("AD18E22X_test\r\n");
	Timer0_Timer(T0CS_CPU,T0SE_FALLEDGE,PSA_EN,T0CKPS_DIV256); //定时10ms

	Timer1_edge_io_mode1();//IO脉宽测量函数模式1


	IPEN = 1;	   	//允许高低优先级
	GIEH=1;
	GIEL=1;
	while(1)
     {
		if(start_flag==3)
		{
			start_flag=1;
			T1PRIE=0;	//关闭中断
			T1PDIE=0;	//关闭中断
			GIEH=0;
			GIEL=0;
			ccpr_temp=(PR1H<<8|PR1L)+1;
			// printf ("PR=%lu us\r\n",ccpr_temp);
			period= ccpr_temp+(TIMER1_T*65536);	//us
			printf ("period=%lu us\r\n",period);
			TIMER1_T=0;
			GIEH=1;
			GIEL=1;
			T1PRIF = 0;
			T1PRIE=1;	//开中断
			T1PDIF = 0;
			T1PDIE=1;	//开中断
		}
     }
}

//高优先级中断服务函数
void interrupt ISR_h (void)
{
//进入中断后系统自动关闭中断
	unsigned char tmp_int;
	if((TMR0IF==1)&&(TMR0IE==1))    //tmr0定时10ms产生中断后PB1翻转
	{
		TMR0IF = 0;                      //清除中断标志
		TMR0   = 0;                       //tmr0从0开始计数
		PB1    = ~PB1;
	}

	if(TMR1IF==1  &&  TMR1IE==1)
	{
		TMR1IF = 0;
		// TMR1H=0X00;
		// TMR1L=0X00;
	    TIMER1_T++;	//针对长脉宽——TIMER1溢出中断，但未发生边沿触发中断
	}
	tmp_int = PIR1;
	if((tmp_int&0X08)==0X08 && T1PRIE == 1)	//上升沿直接的脉宽--周期
    {
		T1PRIF = 0;
		start_flag++; //采集结束
		PC0=~PC0;
		if (start_flag==2)
		{
			TIMER1_T=0;
		}
    }
	// if((tmp_int&0X04)==0X04 && T1PDIE == 1)	//下降沿直接的脉宽--周期
    // {
	// 	T1PDIF = 0;
	// 	start_flag++; //采集结束
	// 	PC0=~PC0;
	// 	if (start_flag==2)
	// 	{
	// 		TIMER1_T=0;
	// 	}
    // }
}

//低优先级中断服务函数
void interrupt low_priority ISR_l (void)
{
//进入中断后系统自动关闭中断

}

