/**********************************************************************************************
* Device      : AD18E22X
* Author      : TANWENBO
* Version     : V0.0.1
* Date        : 2024.08.24
* Description : 演示配置TMR1产生1ms定时
***********************************************************************************************/
#include "AD18E22X.h"
#include "AD18E22X_DEF.h"
#include "common.h"
/*********************************************************************************************
*常用配置字功能说明:
*
*_FINTOSC_DIV1_1L  :  内部 RC 振荡器频率选择
*_FCPU_4T_1L       :  选择指令周期为4T模式
*_SMT_SMV_1L       :  电平选择位
*_LVREN_OFF_1L     :  LVR 使能选择           
*_LVR24V_1L        :  LVR 电压选择2.4V    
*
*_DBGEN_I2C_OFF_2L :  I2C 调试模式使能选择               
*_DBGEN_UART_00_2L :  UART 调试模式使能选择              
*_RESETE_OFF_2L    :  外部复位使能选择           
*_WDTE_OFF_2L      :  WDT 使能选择         
*_TWDT_111_2L      :  看门狗溢出时间及上电复位时间选择         
*
*注意：1.配置字若无特别需求请勿修改；
*      2.其他配置字及相应功能见Datasheet及头文件；
*
************************************************************************************************/
__CONFIG(1,_FINTOSC_DIV1_1L     & _FCPU_4T_1L         & _SMT_SMV_1L     & _LVREN_OFF_1L    & _LVR24V_1L  );
__CONFIG(2,_DBGEN_I2C_OFF_2L    & _DBGEN_UART_00_2L   & _RESETE_OFF_2L  & _WDTE_OFF_2L     & _TWDT_111_2L   );


void main (void)

{
	GPIO_Init();
	TRISA2=0;        //将PA2设置为输出模式
	IPEN = 1;	   	//使能中断优先级
	GIEH=1;         //使能高优先级中断
    TMR1IE=1;       //开启TMR1的中断使能
	TMR1IF=0;       //清除TMR1的中断
	PR1H=0x0F;
	PR1L=0x9F;
    T1CON0=T1CK_FCPU|T1CKPS_DIV1|T1SYNC_EN|TM1_ON;   //使能Timer1定时器;
	while(1)
     {
		NOP();
     }
}
//高优先级中断服务函数
void interrupt ISR_h (void)
{
	//进入中断后系统自动关闭中断
	if(TMR1IF==1  &&  TMR1IE==1)     //计满产生溢出中断
	{
		TMR1IF = 0;
	    PA2=~PA2;
	}
}

//低优先级中断服务函数
void interrupt low_priority ISR_l (void)
{
//进入中断后系统自动关闭中断

}

