/**********************************************************************************************
* Device      : AD18E22X
* Author      : TANWENBO
* Version     : V0.0.1
* Date        : 2024.08.24
* Description : 演示配置不同的时钟源作为TMR1的计数时钟
***********************************************************************************************/

#include "AD18E22X.h"
#include "AD18E22X_DEF.h"
/*********************************************************************************************
*常用配置字功能说明:
*
*_FINTOSC_DIV1_1L  :  内部 RC 振荡器频率选择
*_FCPU_4T_1L       :  选择指令周期为4T模式
*_SMT_SMV_1L       :  电平选择位
*_LVREN_OFF_1L     :  LVR 使能选择           
*_LVR24V_1L        :  LVR 电压选择2.4V    
*
*_DBGEN_I2C_OFF_2L :  I2C 调试模式使能选择               
*_DBGEN_UART_00_2L :  UART 调试模式使能选择              
*_RESETE_OFF_2L    :  外部复位使能选择           
*_WDTE_OFF_2L      :  WDT 使能选择         
*_TWDT_111_2L      :  看门狗溢出时间及上电复位时间选择         
*
*注意：1.配置字若无特别需求请勿修改；
*      2.其他配置字及相应功能见Datasheet及头文件；
*
************************************************************************************************/

__CONFIG(1,_FINTOSC_DIV1_1L     & _FCPU_4T_1L         & _SMT_SMV_1L     & _LVREN_OFF_1L    & _LVR24V_1L  );
__CONFIG(2,_DBGEN_I2C_ON_2L      & _DBGEN_UART_00_2L    & _RESETE_OFF_2L  & _WDTE_OFF_2L     & _TWDT_111_2L   );

/*******************************************************************************
// ----Function: GPIO_Init
// --Parameters: 
// -----Returns: None   
//---------Note:所有IO初始化
*******************************************************************************/

void GPIO_Init(void)
{
     TRISA = 0X00;       //PA口设置为输出模式
     PA0PU = 1;          //PA0上拉关闭
     PA1PU = 1;          //PA1上拉关闭
     PA2PU = 1;          //PA2上拉关闭
     PA4PU = 1;          //PA4上拉关闭
     PA5PU = 1;          //PA5上拉关闭
     PAPD  = 0x3F;       //PA口下拉关闭
     PA0OD = 0;          //PA0 OD关闭
     PA1OD = 0;          //PA1 OD关闭
     PA2OD = 0;          //PA2 OD关闭
     PA4OD = 0;          //PA4 OD关闭
     PA5OD = 0;          //PA5 OD关闭
     TRISB = 0X00;       //PB口设置为输出模式
     PBPU  = 0x3F;       //PB口上拉关闭
     TRISC = 0X00;       //PC口设置为输出模式
     PCPU  = 0x7F;       //PC上拉关闭
     PC6=1;              //注：PC6在低功耗模式下需要关闭上拉并且输出高
     PC6PD = 1;          //PC6口下拉关闭  PC6控制PMOS时需要设置成输入模式，
                         //通过控制上下拉电阻1K实现PMOS开关，减少PMOS开关导致电源电压过充现象       
}

void main (void)
{
	GPIO_Init();
    TMR1IF=0;
	TMR1IE=1;       //开启TMR1中断使能
	IPEN = 1;	   	//使能中断优先级
	GIEH=1;         //使能高优先级中断
    TRISA2=0;       //将PA2设置为输出模式

	PR1H=0x01;
	PR1L=0x8F;
/*-----------------------------------选择FCPU作为timer1的时钟------------------------------------------------------------*/

    //  T1CON0=T1CK_FCPU|T1CKPS_DIV1|TM1_ON;   //使能Timer1定时器；选择FCPU作为timer1的时钟（注意关闭看门狗）100us

/*-----------------------------------选择T0CKI作为timer1的时钟------------------------------------------------------------*/

    // TRISC2=1;      //将PC2设置为输入模式
    // T1CON0=T1CK_T1CKI_PC2|T1CKPS_DIV1|TM1_ON;   //使能Timer1定时器；选择T1CKI(PC2)作为timer1的时钟

/*-----------------------------------选择内部32k作为timer1的时钟------------------------------------------------------------*/
	// T1CON0=T1CK_32K|T1CKPS_DIV1|T1SYNC_DIS|TM1_ON;   //使能Timer1定时器；选择内部32k作为timer1的时钟12.5ms

/*-----------------------------------选择CMP1OUT作为timer1的时钟------------------------------------------------------------*/
	T1CON0=T1CK_CMP1OUT|T1CKPS_DIV1|TM1_ON;   //使能Timer1定时器；选择CMP1OUT输出作为timer1的时钟
	TRISC1 = 1;PC1PU = 1;TRISB1 = 1;PB1PU = 1;      //Pch_PC1,Nch_PB1
	CMP1CON0=CMP1_EN|CMP1PCH_PC1|CMP1NCH_PC0;	//CMP使能


	while(1)
     {
		// NOP();
        PB0 = ~PB0;
        __delay_us(25);
     }
}

//高优先级中断服务函数

void interrupt ISR_h (void)
{
//进入中断后系统自动关闭中断
	if(TMR1IF==1  &&  TMR1IE==1)     //计满产生溢出中断
	{
		TMR1IF = 0;                  //清除TMR1中断
	    PA2=~PA2;                    //IO 翻转
	}

}

//低优先级中断服务函数
void interrupt low_priority ISR_l (void)
{
//进入中断后系统自动关闭中断

}

