/*******************************************************************************
* Device      : AD18E22X
* Author      : SunGuoding
* Version     : V0.0.1
* Date        : 2024.08.24
* Description : 门控翻转模式，测试输入波形的周期
********************************************************************************/

#include <stdio.h>
#include "AD18E22X.h"
#include "AD18E22X_DEF.h"
#include "usart.h"
/*********************************************************************************************
*常用配置字功能说明:
*
*_FINTOSC_DIV1_1L  :  内部 RC 振荡器频率选择
*_FCPU_4T_1L       :  选择指令周期为4T模式
*_SMT_SMV_1L       :  电平选择位
*_LVREN_OFF_1L     :  LVR 使能选择           
*_LVR24V_1L        :  LVR 电压选择2.4V    
*
*_DBGEN_I2C_OFF_2L :  I2C 调试模式使能选择               
*_DBGEN_UART_00_2L :  UART 调试模式使能选择              
*_RESETE_OFF_2L    :  外部复位使能选择           
*_WDTE_OFF_2L      :  WDT 使能选择         
*_TWDT_111_2L      :  看门狗溢出时间及上电复位时间选择         
*
*注意：1.配置字若无特别需求请勿修改；
*      2.其他配置字及相应功能见Datasheet及头文件；
*
************************************************************************************************/
__CONFIG(1,_FINTOSC_DIV1_1L     & _FCPU_4T_1L         & _SMT_SMV_1L     & _LVREN_OFF_1L    & _LVR24V_1L  );
__CONFIG(2,_DBGEN_I2C_OFF_2L     & _DBGEN_UART_00_2L    & _RESETE_OFF_2L  & _WDTE_OFF_2L     & _TWDT_111_2L   );


void GPIO_Init(void);
void Timer3_div(unsigned char T3_CKPS,unsigned char T3_OUTPS);
//==============================================================================================
// ----Function: 主程序
// --Parameters: None
// -----Returns: None
//---------Note: 选择Timer3预分频值为4和后分频值为4
//==============================================================================================
unsigned int  TMR3_count=0;
char TMR3_flag=0;
unsigned int  TIMER3_T=0;
void main (void)
{	

	GPIO_Init();     //所有IO初始化
 	Timer3_div(T3CKPS_DIV4,  T3OUTPS(4));    //Timer3的配置 预分频1：4   后分频1:4
	usart_init();     // TX_PIN: PA1;  RX_PIN: PA2
	printf("Timer3 Gate Test !!!\r\n");
	TMR3ON=1; 	//使能tmr3计数
	//门控
	TRISC0=1;
	TRISC1=1;

	TMR3GE=1;	//Timer3门控功能控制使能
	T3GPOL=1;	//Timer3的门控极性位    	1：Timer3门控为高电平有效;     0：Timer3门控为低电平有效
	T3GTM=1;	//Timer3的门控翻转模式位    1：使能Timer3门控翻转模式;      0：禁止Timer3门控翻转模式
	T3GCK1=0;	//Timer3门控源选择位    	00：PC0引脚  01：PC1引脚  10：CMP0的输出  11：CMP1的输出
	T3GCK0=1;

	TMR3GIF=0;
	TMR3GIP=1;
	TMR3GIE=1;

    IPEN  = 1;//高低优先级中断使能位
	GIEH  = 1;//使能高优先级总中断
    GIEL  = 0;//使能低优先级总中断

	while(1)
	{
		if(TMR3_flag)
		{
			TMR3_flag=0;
			TMR3_count+=TIMER3_T*(PR3+1);
			printf("TMR3_G= %d \r\n",TMR3_count);
			TMR3=0;
			TMR3ON=1;
			TIMER3_T=0;			
		}
	}

}

//高优先级中断服务函数
void interrupt ISR_h (void)
{
//进入中断后系统自动关闭中断
	if(TMR3IF  &&  TMR3IE)
	{
		TMR3IF = 0;		//Timer3中断标志位清0
		TMR3=0;			//必须添加，门控中断在溢出中断产生时会发生不能清除情况，导致记录的门控时间变为：多次溢出时间+门控时间。		
		TIMER3_T++;
	}
	if(TMR3GIF  &&  TMR3GIE)
	{
		TMR3GIF = 0;	//Timer3中断标志位清0
		TMR3_flag=1;
		TMR3_count=TMR3;		
		TMR3ON=0;
	    PC3 =~PC3;		//PC3翻转
	}	
}

//低优先级中断服务函数
void interrupt low_priority ISR_l (void)
{
//进入中断后系统自动关闭中断

}


/*******************************************************************************
// ----Function: GPIO_Init
// --Parameters:
// -----Returns: None
//---------Note:所有IO初始化
*******************************************************************************/
void GPIO_Init(void)
{
     TRISA = 0X00;       //PA口设置为输出模式
     PA0PU = 1;          //PA0上拉关闭
     PA1PU = 1;          //PA1上拉关闭
     PA2PU = 1;          //PA2上拉关闭
     PA4PU = 1;          //PA4上拉关闭
     PA5PU = 1;          //PA5上拉关闭
     PAPD  = 0x3F;       //PA口下拉关闭
     PA0OD = 0;          //PA0 OD关闭
     PA1OD = 0;          //PA1 OD关闭
     PA2OD = 0;          //PA2 OD关闭
     PA4OD = 0;          //PA4 OD关闭
     PA5OD = 0;          //PA5 OD关闭
     TRISB = 0X00;       //PB口设置为输出模式
     PBPU  = 0x3F;       //PB口上拉关闭
     TRISC = 0X00;       //PC口设置为输出模式
     PCPU  = 0x7F;       //PC上拉关闭
     PC6=1;              //注：PC6在低功耗模式下需要关闭上拉并且输出高
     PC6PD = 1;          //PC6口下拉关闭  PC6控制PMOS时需要设置成输入模式，
                         //通过控制上下拉电阻1K实现PMOS开关，减少PMOS开关导致电源电压过充现象 
}

/*******************************************************************************
 * 【T3_CKPS】:TIMER3的输入时钟分频
 *                    T3CKPS_DIV1    TIMER3输入时钟1:1分频
 *                    T3CKPS_DIV4    TIMER3输入时钟1:4分频
 *                    T3CKPS_DIV8    TIMER3输入时钟1:8分频
 *                    T3CKPS_DIV16   TIMER3输入时钟1:16分频
 * 【T3_OUTPS】: TIMER3的输入时钟后分频
 * 					  T3OUTPS(x)    x:分频选择，x取值范围：1~32
*******************************************************************************/
void Timer3_div(unsigned char T3_CKPS,unsigned char T3_OUTPS)
{
	PR3 = 0X63;	  //周期

	TMR3  = 0X00;	  //初值
	T3CON0 |= T3_CKPS;   //预分频
	T3CON0 |= T3_OUTPS;   //后分频
	TMR3IF = 0;      //清中断标志
	TMR3IP = 1;		 //高优先级中断
	TMR3IE = 1;      //开TMR3中断
}
