/**********************************************************************************************
* Device      : AD18E22X
* Author      : ADUC AE Team
* Version     : V0.0.1
* Date        : 2024.08.24
* Description : ADC配置采集通道为PB1,参考电压为VDD，通过串口（PA1）输出对应ADC值   波特率 = 19200
*               串口回环测试：返回收到的数据
***********************************************************************************************/
#include "AD18E22X.h"
#include <stdio.h>
#include "periph.h"
#include "usart.h"

/*********************************************************************************************
*常用配置字功能说明:
*
*_FINTOSC_DIV1_1L  :  内部 RC 振荡器频率选择
*_FCPU_4T_1L       :  选择指令周期为4T模式
*_SMT_SMV_1L       :  电平选择位
*_LVREN_OFF_1L     :  LVR 使能选择           
*_LVR24V_1L        :  LVR 电压选择2.4V    
*
*_DBGEN_I2C_OFF_2L :  I2C 调试模式使能选择               
*_DBGEN_UART_00_2L :  UART 调试模式使能选择              
*_RESETE_OFF_2L    :  外部复位使能选择           
*_WDTE_OFF_2L      :  WDT 使能选择         
*_TWDT_111_2L      :  看门狗溢出时间及上电复位时间选择         
*
*注意：1.配置字若无特别需求请勿修改；
*      2.其他配置字及相应功能见Datasheet及头文件；
*
************************************************************************************************/
__CONFIG(1,_FINTOSC_DIV1_1L     & _FCPU_4T_1L         & _SMT_SMV_1L     & _LVREN_OFF_1L    & _LVR24V_1L  );
__CONFIG(2,_DBGEN_I2C_OFF_2L     & _DBGEN_UART_00_2L    & _RESETE_OFF_2L  & _WDTE_OFF_2L     & _TWDT_111_2L   );

unsigned short VOLT ;
unsigned char str1[32] = {0xB4,0xAE,0xBF,0xDA,0xBB,0xD8,0xBB,0xB7,0xB2,0xE2,0xCA,0xD4,0xA3,0xBA,0xB7,0xB5,0xBB,0xD8,0xCA,0xD5,0xB5,0xBD,0xB5,0xC4,0xCA,0xFD,0xBE,0xDD,0xA3,0xA1,0x0D,0x0A};

//==============================================================================================
// ----Function: 主程序
// --Parameters: None
// -----Returns: None
//---------Note:
//==============================================================================================
void main(void)
{
   unsigned char i= 0;
    GPIO_Init();
    usart_init();     // TX_PIN: PA1;  RX_PIN: PA2
    ADC_Config();         //ADC初始化

    printf("***********************************\r\n");
    for(i = 0;i < 32;i++)printf("%c",str1[i]);
    printf("***********************************\r\n");
    printf("                                   \r\n");

    RCIP      = 1;	    //高优先级
    RCIF      = 0;     //清除中断标志
    RCIE      = 1;     //使能接收中断

    IPEN       = 1;     //允许高低优先级
    GIEL       = 0;     //关闭低优先级中断
    GIEH       = 1;     //开启高优先级中断
    // TRISB1=0;
    while(1)
    {
      // PB1=~PB1;
      VOLT =ADC_SampleFilter();     //获取采集值
      printf("ADC_Vol =  %d \r\n",VOLT);      //打印AD转换数据
      __delay_ms(100);
    }
}
//高优先级中断服务函数

void interrupt ISR_h (void)
{
//进入中断后系统自动关闭中断
  if(RCIE == 1 && RCIF == 1 && RCIP == 1)
	{
		RCIF = 0;
		while(!TXIF)continue;
		TXREG = RCREG;
		TXIF = 0;
	}


}

//低优先级中断服务函数

void interrupt low_priority ISR_l (void)
{


}

